Index: src/sas/qtgui/Perspectives/Fitting/UnitTesting/FittingUtilitiesTest.py
===================================================================
--- src/sas/qtgui/Perspectives/Fitting/UnitTesting/FittingUtilitiesTest.py	(revision 7248d75d0e91daa6e6c6163bb53fa76c1c8898e3)
+++ src/sas/qtgui/Perspectives/Fitting/UnitTesting/FittingUtilitiesTest.py	(revision b1e36a387414e3a8dc9726bbef5c0651364e2b64)
@@ -114,14 +114,9 @@
 
         # Test the resulting model
-        self.assertEqual(model.rowCount(), 5)
+        self.assertEqual(model.rowCount(), 3)
         self.assertTrue(model.item(0).isCheckable())
         self.assertEqual(model.item(0).text(), "sld_core")
-        self.assertFalse(model.item(3).hasChildren())
         self.assertEqual(model.item(1).text(), "radius")
         self.assertEqual(model.item(2).text(), "sld_solvent")
-        self.assertEqual(model.item(3).text(), "sld1")
-
-        self.assertEqual(model.item(4).text(), "thickness1")
-        self.assertTrue(model.item(4).hasChildren())
 
     def testAddSimpleParametersToModel(self):
@@ -139,5 +134,5 @@
 
         # Test the resulting model
-        self.assertEqual(model.rowCount(), 5)
+        self.assertEqual(model.rowCount(), 3)
         self.assertTrue(model.item(0).isCheckable())
         self.assertEqual(model.item(0).text(), "sld_core")
Index: src/sas/qtgui/Perspectives/Fitting/UnitTesting/FittingWidgetTest.py
===================================================================
--- src/sas/qtgui/Perspectives/Fitting/UnitTesting/FittingWidgetTest.py	(revision 351b53ec7df03f611b0f054c0dde289dc8a5089f)
+++ src/sas/qtgui/Perspectives/Fitting/UnitTesting/FittingWidgetTest.py	(revision b1e36a387414e3a8dc9726bbef5c0651364e2b64)
@@ -165,5 +165,6 @@
 
         # invoke the method by changing the index
-        self.widget.cbCategory.setCurrentIndex(1)
+        category_index = self.widget.cbCategory.findText("Shape-Independent")
+        self.widget.cbCategory.setCurrentIndex(category_index)
 
         # test the model combo content
@@ -190,5 +191,6 @@
         self.widget.show()
         # Change the category index so we have some models
-        self.widget.cbCategory.setCurrentIndex(1)
+        category_index = self.widget.cbCategory.findText("Shape-Independent")
+        self.widget.cbCategory.setCurrentIndex(category_index)
 
         # check the enablement of controls
@@ -202,5 +204,5 @@
         self.widget.SASModelToQModel = MagicMock()
         self.widget.createDefaultDataset = MagicMock()
-        self.widget.calculateDataForModel = MagicMock()
+        self.widget.calculateQGridForModel = MagicMock()
         # 
         # Now change the model
@@ -211,5 +213,5 @@
         self.assertTrue(self.widget.createDefaultDataset.called)
         self.assertTrue(self.widget.SASModelToQModel.called)
-        self.assertFalse(self.widget.calculateDataForModel.called)
+        self.assertFalse(self.widget.calculateQGridForModel.called)
 
         # Let's set a dummy index on widget
@@ -219,6 +221,6 @@
         self.assertEqual(self.widget.cbModel.currentText(),'be_polyelectrolyte')
 
-        # Observe calculateDataForModel called
-        self.assertTrue(self.widget.calculateDataForModel.called)
+        # Observe calculateQGridForModel called
+        self.assertTrue(self.widget.calculateQGridForModel.called)
 
     def testSelectFactor(self):
@@ -228,5 +230,6 @@
         self.widget.show()
         # Change the category index so we have some models
-        self.widget.cbCategory.setCurrentIndex(1)
+        category_index = self.widget.cbCategory.findText("Shape-Independent")
+        self.widget.cbCategory.setCurrentIndex(category_index)
         # Change the model to one that supports structure factors
         model_index = self.widget.cbModel.findText('fractal_core_shell')
@@ -296,5 +299,5 @@
         # Check the index
 
-    def testCalculateDataForModel(self):
+    def testCalculateQGridForModel(self):
         """
         Check that the fitting 1D data object is ready
@@ -303,5 +306,5 @@
         threads.deferToThread = MagicMock()
         # Call the tested method
-        self.widget.calculateDataForModel()
+        self.widget.calculateQGridForModel()
         # Test the mock
         self.assertTrue(threads.deferToThread.called)
@@ -328,5 +331,6 @@
         self.widget.show()
         # Change the category index so we have a model with no poly
-        self.widget.cbCategory.setCurrentIndex(1)
+        category_index = self.widget.cbCategory.findText("Shape-Independent")
+        self.widget.cbCategory.setCurrentIndex(category_index)
         # Check the poly model
         self.assertEqual(self.widget._poly_model.rowCount(), 0)
@@ -356,5 +360,6 @@
         self.widget.show()
         # Change the category index so we have a model available
-        self.widget.cbCategory.setCurrentIndex(2)
+        category_index = self.widget.cbCategory.findText("Shapes")
+        self.widget.cbCategory.setCurrentIndex(category_index)
 
         # Check the magnetic model
@@ -384,6 +389,8 @@
         self.widget.show()
         # Change the model to multi shell
-        self.widget.cbCategory.setCurrentIndex(2)
-        self.widget.cbModel.setCurrentIndex(4)
+        category_index = self.widget.cbCategory.findText("Shapes")
+        self.widget.cbCategory.setCurrentIndex(category_index)
+        model_index = self.widget.cbModel.findText("core_multi_shell")
+        self.widget.cbModel.setCurrentIndex(model_index)
 
         # Assure we have the combobox available
